@@ -1,4 +1,5 @@
 import datetime
+import logging
 import random
 import uuid
 from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
@@ -6,10 +7,14 @@ from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 import pandas as pd
 
 from gantry.exceptions import GantryLoggingException
-from gantry.logger.utils import _check_sample_rate
+from gantry.logger.constants import BatchType, Delimiter, UploadFileType
+from gantry.logger.types import DataLink, DataLinkElement
+from gantry.logger.utils import _check_sample_rate, get_file_linecount
 from gantry.utils import check_event_time_in_future, compute_feedback_id
 from gantry.validators import validate_logged_field_datatype
 
+logger = logging.getLogger(__name__)
+
 
 def _build_prediction_and_feedback_events(
     application: str,
@@ -19,7 +24,7 @@ def _build_prediction_and_feedback_events(
     inputs: Union[List[dict], pd.DataFrame],
     outputs: Union[List[dict], List[Any], pd.DataFrame],
     feedbacks: Union[List[dict], pd.DataFrame],
-    version: List[Union[str, int]] = None,
+    version: Optional[Union[str, int]] = None,
     feedback_keys: Optional[List[str]] = None,
     ignore_inputs: Optional[List[str]] = None,
     sample_rate: float = 1.0,
@@ -34,7 +39,6 @@ def _build_prediction_and_feedback_events(
             continue
 
         feedback_id = {k: inputs[idx][k] for k in (feedback_keys or [])}
-        version_ = version[idx] if version is not None else None  # type: ignore
 
         event = {}
 
@@ -45,7 +49,7 @@ def _build_prediction_and_feedback_events(
                 inputs[idx],
                 outputs[idx],
                 application,
-                version_,
+                version,
                 feedback_keys,
                 ignore_inputs,
                 feedback_id=None,
@@ -59,7 +63,7 @@ def _build_prediction_and_feedback_events(
             application,
             feedback_id,
             feedbacks[idx],
-            version_,  # type: ignore
+            version,  # type: ignore
             timestamp,
         )
 
@@ -150,12 +154,12 @@ def _build_prediction_events(
     timestamp_idx: Iterable,
     context: Dict[str, str],
     environment: str,
-    version: Optional[List[Union[str, int]]],
+    version: Optional[Union[str, int]],
     feedback_keys: Optional[List[str]] = None,
     ignore_inputs: Optional[List[str]] = None,
     feedback_ids: Optional[List[dict]] = None,
     sample_rate: float = 1.0,
-    batch_id: str = None,
+    batch_id: Optional[str] = None,
     tags: Optional[Dict[str, str]] = None,
 ):
     _check_sample_rate(sample_rate)
@@ -166,7 +170,6 @@ def _build_prediction_events(
             continue
 
         feedback_id = feedback_ids[idx] if feedback_ids else None
-        version_ = version[idx] if version is not None else None
 
         events.append(
             _build_prediction_event(
@@ -175,7 +178,7 @@ def _build_prediction_events(
                 inputs[idx],
                 outputs[idx],
                 application,
-                version_,
+                version,
                 feedback_keys,
                 ignore_inputs,
                 batch_id=batch_id,
@@ -259,9 +262,74 @@ def _build_prediction_event(
     }
 
 
-def _build_batch_meta(event_len: int, type_: str) -> dict:
-    return {
-        "size": event_len,
-        "started_at": datetime.datetime.utcnow().isoformat(),
-        "type": type_,
-    }
+def _build_data_link(  # noqa: C901
+    application: str,
+    environment: Optional[str] = None,
+    version: Optional[Union[int, str]] = None,
+    timestamp: Optional[str] = None,
+    inputs: List[str] = [],
+    outputs: List[str] = [],
+    feedbacks: List[str] = [],
+    tags: List[str] = [],
+    feedback_id: List[str] = [],
+    feedback_keys: Optional[List[str]] = None,
+    filepath: Optional[str] = None,
+    events: Optional[List] = None,
+    batch_type: BatchType = BatchType.RECORD,
+) -> DataLink:
+    if filepath:
+        # Get info for tracking batch during processing.
+        num_events = get_file_linecount(filepath) - 1  # Subtract the header line.
+        file_type = UploadFileType.CSV_WITH_HEADERS
+    elif events:
+        num_events = len(events)
+        file_type = UploadFileType.EVENTS_BYTES
+    else:
+        raise GantryLoggingException("Invalid data params. Need filepath or events list")
+    logger.info(f"Processing {num_events} lines.")
+
+    if version is not None:
+        version = str(version)
+
+    # Read the headers of the file, infer and build linking datastruct.
+    data_link = DataLink(
+        file_type=file_type,
+        batch_type=batch_type,
+        num_events=num_events,
+        application=application,
+        version=version,
+        log_timestamp=datetime.datetime.utcnow().isoformat(),
+        tags={"env": DataLinkElement(val=environment)},
+    )
+
+    if filepath:
+        with open(filepath, "r") as f_in:
+            headers_line = f_in.readline().split(Delimiter.COMMA.value)
+            data_line = f_in.readline().split(Delimiter.COMMA.value)
+            if len(headers_line) != len(data_line):
+                raise GantryLoggingException("Header row length does not match data row length.")
+
+            for col_index, raw_header in enumerate(headers_line):
+                header = raw_header.strip()
+                if header == timestamp or (not timestamp and header.startswith("timestamp")):
+                    data_link.timestamp[header] = DataLinkElement(ref=col_index)
+                elif header in outputs or header.startswith("output"):
+                    data_link.outputs[header] = DataLinkElement(ref=col_index)
+                elif header in feedbacks or header.startswith("feedback"):
+                    data_link.feedback[header] = DataLinkElement(ref=col_index)
+                elif header in tags or header.startswith("tags"):
+                    data_link.tags[header] = DataLinkElement(ref=col_index)
+                elif len(inputs) == 0 or header in inputs or header.startswith("input"):
+                    data_link.inputs[header] = DataLinkElement(ref=col_index)
+
+                if header in feedback_id or header == "feedback_id":
+                    data_link.feedback_id[header] = DataLinkElement(ref=col_index)
+                elif feedback_keys is not None and header in feedback_keys:
+                    data_link.feedback_keys.append(header)
+
+    if data_link.tags["env"].ref is None and data_link.tags["env"].val is None:
+        raise GantryLoggingException(
+            "Please initialize gantry logger with 'environment' or specify an 'env' tag."
+        )
+
+    return data_link
