@@ -1,13 +1,16 @@
 import functools
+import json
 import logging
 import os
 import subprocess
+from itertools import islice
 from typing import Any, List, Union
 
 import pandas as pd
 
 from gantry.exceptions import GantryBatchCreationException, GantryLoggingException
 from gantry.logger.stores import APILogStore, BaseLogStore
+from gantry.serializers import EventEncoder
 
 logger = logging.getLogger(__name__)
 
@@ -91,3 +94,11 @@ def get_file_linecount(filepath):
     if len(last_line) > 0 and not last_line.endswith("\n"):
         line_count += 1
     return line_count
+
+
+def _build_batch_iterator(iterable, batch_size):
+    iterator = iter(iterable)
+    batch = list(islice(iterator, batch_size))
+    while batch:
+        yield json.dumps(batch, cls=EventEncoder).encode("utf-8")
+        batch = list(islice(iterator, batch_size))
