@@ -12,10 +12,16 @@ from gantry.query.core.constants import STATUS_PARAM
 from gantry.query.core.dataframe import GantryDataFrame
 from gantry.query.core.distance import GantryDistance
 from gantry.query.core.metric import GantryMetric
-from gantry.query.core.utils import check_response, get_application_views
+from gantry.query.core.utils import (
+    check_response,
+    get_application_node_id,
+    get_application_views,
+)
 
 logger = logging.getLogger(__name__)
 
+DEFAULT_VIEW_COLOR = "#FF8900"
+
 
 class GantryQuery:
     def __init__(self, api_client: APIClient) -> None:
@@ -81,6 +87,7 @@ class GantryQuery:
         environment: Optional[str] = None,
         filters: Optional[List[Dict]] = None,
         view: Optional[str] = None,
+        tags: Optional[dict] = None,
     ) -> GantryDataFrame:
         """
         Query for a window of data for an application and version with a given start, end
@@ -94,12 +101,17 @@ class GantryQuery:
                 If not provided, defaults to now
             version (optional, int or str): application version.
             environment: (optional, str) - environment string to pull application for.
+                This parameter takes precedence over a tags["env"] value in case
+                tags are passed.
             filters: (optional, list[dict]) - optional filters for the query. Use this
                 parameter only if you are familiar with the dict representation of
                 the filters.
             view: (optional, str) - The view name to query data from. A view is a saved
                 configuration of filters/start_time/end_time, so this parameter cannot
                 be used with start_time, end_time or filters parameters.
+            tags: (optional, dict) - Optional tags to filter data. Each record has tags
+                associated that were provided at ingestion time. The environment parameter
+                overrides an "env" tag.
 
         Returns:
             Gantry Dataframe with the data.
@@ -120,7 +132,7 @@ class GantryQuery:
                 )
 
             return GantryDataFrame.from_view(
-                self._api_client, application, view, version, environment
+                self._api_client, application, view, version, environment, tags=tags
             )
 
         start_time = start_time or "-24H"
@@ -134,6 +146,7 @@ class GantryQuery:
             start_time=start_time,
             end_time=end_time,
             filters=filters,
+            tags=tags,
         )
 
     def get_current_feedback_schema(self, application: str):
@@ -235,6 +248,74 @@ class GantryQuery:
         """
         raise NotImplementedError()
 
+    def create_view(
+        self,
+        name: str,
+        application: str,
+        start_time: Optional[datetime.datetime] = None,
+        end_time: Optional[datetime.datetime] = None,
+        duration: Optional[datetime.timedelta] = None,
+        version: Optional[str] = None,
+        tag_filters: Optional[Dict[str, str]] = None,
+        data_filters: Optional[List[Dict]] = None,
+    ) -> None:
+        """Create a view for an application.
+
+        Args:
+            name (str): The name of the view.
+            application (str): The application in which the view will be created.
+            start_time (optional, datetime): Start time of the view. If you pass start_time,
+                you need to specify end_time and cannot set duration.
+            end_time (optional, datetime): End time of the view. If you pass end_time, you need to
+                specify start_time also and cannot set duration.
+            duration (optional, timedelta): Time window of the view. End time will be present time.
+                For example, timedelta(days=1) will look 24hs back.
+                IMPORTANT: if exact datetimes want to be provided, use start_time/end_time instead.
+            version (optional, str): The version of the app that the view should use.
+            tag_filters (optional, dict): A dictionary with tags to filter the data of the view.
+            data_filters (optional, list[dict]): A list of Gantry-formatted filters. For example:
+
+                .. code-block:: python
+
+                    [
+                        {
+                            'feature_name': 'inputs.loan_amount',
+                            'lower_bound': '100',
+                            'upper_bound': '200',
+                        }
+                    ]
+
+        """
+        data = {
+            "name": name,
+            "model_node_id": get_application_node_id(
+                self._api_client, application, version=version
+            ),
+            "tag_filters": tag_filters or {},
+            "data_filters": data_filters or [],
+            "details": {"color": DEFAULT_VIEW_COLOR},
+        }
+
+        if duration:
+            if start_time or end_time:
+                raise ValueError("Cannot provide duration and start_time/end_time at the same time")
+
+            data["duration"] = isodate.duration_isoformat(duration)
+
+        if start_time or end_time:
+            if not (start_time and end_time):
+                raise ValueError("Need to provide both start_time and end_time")
+
+            data["start_time"] = start_time  # type: ignore
+            data["end_time"] = end_time  # type: ignore
+
+        if not (duration or start_time or end_time):
+            raise ValueError("Need to provide duration or start_time/end_time")
+
+        response = self._api_client.request("POST", "/api/v1/views", json=data)
+        check_response(response)
+        return None
+
     def list_application_views(
         self,
         application: str,
