@@ -54,6 +54,21 @@ def list_applications() -> List[str]:
     return globals._Query.list_applications()  # type: ignore[union-attr]
 
 
+@_query_alias
+def create_view(
+    application: str,
+    name: str,
+    version: Optional[str] = None,
+    tag_filters: Optional[Dict[str, str]] = None,
+    data_filters: Optional[List[Dict]] = None,
+    duration: Optional[datetime.timedelta] = None,
+    start_time: Optional[datetime.datetime] = None,
+    end_time: Optional[datetime.datetime] = None,
+) -> None:
+    validate_init()
+    return globals._Query.create_view(**locals())  # type: ignore[union-attr,return-value]
+
+
 @_query_alias
 def list_application_versions(application: str) -> List[Tuple[int, str]]:
     validate_init()
@@ -75,6 +90,7 @@ def query(
     environment: Optional[str] = None,
     filters: Optional[List[Dict]] = None,
     view: Optional[str] = None,
+    tags: Optional[dict] = None,
 ) -> GantryDataFrame:
     validate_init()
     return globals._Query.query(**locals())  # type: ignore[union-attr]
