@@ -10,7 +10,6 @@ from typing import Any, Dict, List, Optional, Tuple
 
 from dateutil import parser
 
-from gantry.exceptions import GantryLoggingException
 from gantry.serializers import EventEncoder
 
 logger = logging.getLogger(__name__)
@@ -31,9 +30,7 @@ def to_datetime(s: str) -> datetime.datetime:
             dt = datetime.datetime.strptime(s, "%Y-%m-%dT%H:%M:%S.%f")
         except Exception:
             dt = parser.parse(s)
-    if dt.tzinfo is None or dt.tzinfo.utcoffset(dt) is None:
-        # check if datetime is already naive
-        # https://docs.python.org/3/library/datetime.html#determining-if-an-object-is-aware-or-naive
+    if _is_offset_naive(dt):
         return dt
 
     naive_dt = dt.astimezone(datetime.timezone.utc).replace(tzinfo=None)
@@ -80,19 +77,24 @@ def to_timestamp(dt) -> float:
     return (dt - datetime.datetime(1970, 1, 1)).total_seconds()
 
 
-def check_event_time_in_future(event_timestamp: datetime.datetime) -> None:
+def _is_offset_naive(d: datetime.datetime) -> bool:
+    # https://docs.python.org/3/library/datetime.html#determining-if-an-object-is-aware-or-naive
+    aware = d.tzinfo is not None and d.tzinfo.utcoffset(d) is not None
+    return not aware
+
+
+def check_event_time_in_future(event_timestamp: datetime.datetime) -> bool:
     """
     Raises an error if the event timestamp is in the future.
-    Note, `event_timestamp` is assumed to be in UTC.
+    Note, `event_timestamp` is assumed to be in UTC. This
+    method will handle both offset-naive and offset-aware event_timestamp
     """
-    current_time = datetime.datetime.utcnow()
-
-    if event_timestamp > current_time:
-        raise GantryLoggingException(
-            "Cannot log events from the future. "
-            f"Event timestep is {event_timestamp}, but current time is {current_time}. "
-            "Please check your event times and re-submit all."
-        )
+    current_time = (
+        datetime.datetime.utcnow()
+        if _is_offset_naive(event_timestamp)
+        else datetime.datetime.now(datetime.timezone.utc)
+    )
+    return event_timestamp > current_time
 
 
 def compute_feedback_id(inputs: Dict[str, Any], feedback_keys: Optional[List[str]] = None) -> str:
